`pyfortified-requests` is written and maintained by many contributors.

pyfortified-requests: Authors
`````````````````````````````

We'd like to thank the following people who have contributed to the `pyfortified-requests` repository.

- Avital Tzubeli
- Ian Molee <ian@tune.com>
- Jeff Tanner <jeff00seattle@gmail.com>
- Lee Brown <lee@tune.com>
- Ohad Lahav <ohad@tune.com>
- Stas Yasinov
- Tuli Uchitel
- Zaq? Wiedmann <zaq@tune.com>
